@@ -11,7 +11,7 @@ use HTML::ParseBrowser;
 use Mojo::ByteStream;
 use version 0.77;
 
-our $VERSION = 0.06;
+our $VERSION = '0.07';
 
 sub register {
     my ($self, $app, $config) = @_;
@@ -41,6 +41,8 @@ sub register {
 
             $local_base = $c->url_for( $local_base ) if $local_base;
 
+            $config->{no_file} = 1 if $config->{js};
+
             my $js = $config->{no_file} ? 
                 qq~<script type="text/javascript">$file</script>~ :
                 qq~<script type="text/javascript" src="$local_base$file"></script>~;
@@ -61,6 +63,8 @@ sub register {
                           my ($file,$config) = @{ $_ };
                           my $local_base = $config->{no_base} ? '' : $base;
 
+                          $config->{no_file} = 1 if $config->{js};
+
                           $local_base = $c->url_for( $local_base ) if $local_base;
 
                           if ( $config->{no_file} and $config->{on_ready} ) {
@@ -136,7 +140,7 @@ Mojolicious::Plugin::JSLoader - move js loading to the end of the document
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
